@@ -1,23 +1,23 @@
-library(sp)
-library(spacetime)
-library(xts)
+suppressPackageStartupMessages(library(sp))
+suppressPackageStartupMessages(library(spacetime))
+suppressPackageStartupMessages(library(xts))
 
 # example 0: construction with STFDF:
 
-library(maps)
+suppressPackageStartupMessages(library(maps))
 states.m = map('state', plot=FALSE, fill=TRUE)
 IDs <- sapply(strsplit(states.m$names, ":"), function(x) x[1])
     
-library(maptools)
+suppressPackageStartupMessages(library(maptools))
 states = map2SpatialPolygons(states.m, IDs=IDs)
 
-library(plm)
+suppressPackageStartupMessages(library(plm))
 data(Produc)
 
 yrs = 1970:1986
 time = xts(1:17, as.POSIXct(paste(yrs, "-01-01", sep=""), tz = "GMT"))
 # deselect District of Columbia, polygon 8, which is not present in Produc:
-Produc.st = STFDF(states[-8], time, Produc[(order(Produc[2], Produc[1])),])
+Produc.st = STFDF(states[-8], time, Produc[(order(Produc[,2], Produc[,1])),])
 #stplot(Produc.st[,,"unemp"], yrs)
 
 # example 1: st from long table, with states as Spatial object:
@@ -38,7 +38,7 @@ x = stConstruct(Produc, "State", "time", states[-8])
 class(x)
 #stplot(x[,,"unemp"], yrs)
 
-library(rgdal)
+suppressPackageStartupMessages(library(rgdal))
 # stConstruct multivariable, time-wide
 fname = system.file("shapes/sids.shp", package="maptools")[1]
 nc = readOGR(fname)
